from argparse import Namespace, _SubParsersAction

from mdrsclient.api import FolderApi
from mdrsclient.commands.base import BaseCommand
from mdrsclient.exceptions import IllegalArgumentException
from mdrsclient.models import FolderAccessLevel


class ChaclCommand(BaseCommand):
    @classmethod
    def register(cls, parsers: _SubParsersAction) -> None:
        command = cls()
        chacl_parser = parsers.add_parser("chacl", help="change the folder access level")
        chacl_parser.add_argument("access_level", help="access level (private, cbs_open, pw_open)")
        chacl_parser.add_argument("-r", "--recursive", help="change access levels recursively", action="store_true")
        chacl_parser.add_argument("-p", "--password", help="password to set when access level is `pw_open`")
        chacl_parser.add_argument("remote_path", help="remote folder path (remote:/lab/path/)")
        chacl_parser.set_defaults(func=command.chacl)

    def chacl(self, args: Namespace) -> None:
        (remote, laboratory_name, r_path) = self._parse_remote_host_with_path(args.remote_path)
        r_path = r_path.rstrip("/")
        access_level = FolderAccessLevel.key2id(args.access_level)
        if access_level is None:
            raise IllegalArgumentException(
                "Invalid `access_level` parameter. must be `private`, `cbs_open` or `pw_open`."
            )
        connection = self._create_connection(remote)
        laboratory = self._find_laboratory(connection, laboratory_name)
        folder = self._find_folder(connection, laboratory, r_path)
        folder_api = FolderApi(connection)
        folder_api.acl(folder.id, access_level, args.recursive, args.password)
